.. rubric:: Deprecated

- The module `!xotl.tools.future.graphlib`:mod: is deprecated.  We now depend on
  `graphlib-backport <https://pypi.org/project/graphlib-backport/_>`__ on Python
  versions before 3.9 and use that backport.

  We no longer maintain the backport, and neither do we run any tests.
